pub struct ClientId(/* private fields */);Expand description
Specifies the Client the entity belongs to. This allows multiple Clients to co-exist inside the same World. Note that while this uses a spru::player::Id as the id, this does not mean the attached game piece belongs to that player, only that it is their ‘view’ of the game piece.